﻿#define where I am working in the file system
$mypath=$MyInvocation.MyCommand.Path
$mypath=Split-Path $mypath -Parent

#presumes a file called online.txt exists in current directory
$myinput=Test-Path -path $mypath\online.txt
if ($myinput) {
    $mydevices=Get-Content $mypath\online.txt
} else {
    write-host "No input file. Aborting.  Please create a text file of device names or IPs as $mypath\offline.txt" -BackgroundColor DarkRed
    exit
}

#presumes a file called output.txt exists in current directory (for user-readable results)
    #clear previous results, if any
    $myoutput=Test-Path -path $mypath\output.txt
    if ($myoutput) {
        Clear-Content "$mypath\output.txt"
    }


#presumes a file called double_check.txt exists in current directory (for machine-readable results)
    #clear previous results, if any
    $myoutput=Test-Path -path $mypath\double-check.txt
    if ($myoutput) {
        Clear-Content "$mypath\double-check.txt"
    }

#devices can have several issues
#no fw service (ie not installed) -- distribute
#fw service stopped (and also may not start)
#fw server wrong
#configed right, bad cert
#is it running? and is server right?  if so, we likely need to kill certs and restart client

#one way to test communication is to look at the model number on server and on device, we'll use api call to read server model

# Server fqdn and creds are needed
# we'll assume the local admin might have connected...save some time typing in fqdn
$key_exists=test-path -path "HKCU:\SOFTWARE\FileWave\FileWave Admin\"
if ($key_exists) { 
    $my_server_reg=Get-ItemProperty -Path "HKCU:\SOFTWARE\FileWave\FileWave Admin\"
    $defaultValue = $my_server_reg.lastServerAddr
    $server = Read-Host -Prompt "`nWhat is the FQDN of your FileWave Server? Or press enter to accept the default [$($defaultValue)]"
    if (!$server) {$server=$defaultValue}
} else {
    $server = Read-Host -Prompt "`nWhat is the FQDN of your FileWave Server?"
}

# Getting the API token is probably the hardest part for the user
Write-Host "`nIf you don't know your API token, check out this article: https://go.filewave.com/api-token"
$token = Read-Host -Prompt "`nEnter your valid base64 API Token (like ezPyMDRlD2UyLTNjN3ItNGNmMS05YjQ5LTkxMmVmYzEzODZmNn0=)"

foreach ($computer in $mydevices) {
    $model_api=& c:\windows\system32\curl.exe -s -k -H "Authorization: $token" https://$server/filewave/api/fwserver/model_info
    $model_api=$model_api | convertfrom-json
    $model=$model_api.model_number

    $online=$false
    try{
        #try to resolve the name
        $Connection = Test-Connection -ComputerName $Computer -Count 1 -Quiet
    }catch{
        #Catching errors...machine offline
        $Connection= $false
    }
     if (!$Connection) {
        #device not online...
        write-host "$computer, Not online"
    } else {
        #device online, so let's just see if the service is there
        try { 
        #read the version of the filewave client exe
        $files= get-item "\\$computer\c$\Program Files (x86)\FileWave\fwcld.exe" -ErrorAction Stop
        $version=$files.VersionInfo.ProductVersion.SubString(0,6) 
        } catch {write-host failed $computer}

        $time=Get-Date
        write-host "$computer, $time, online, version $version"
            #call psexec run our batch
            $upgrade=""
            try { 
            $result=& $mypath\pstools\PsExec.exe \\$computer -nobanner -c $mypath\fix_fwclient.bat $model $server
            
            #if the model number can't be read from the device, then the client is messed up or not there, will attempt to fix
            if ($result -match "nothing") {
                $upgrade=""
                write-host no client service, installing fwclient
                #copy the msi over, run installer
                Copy-Item "$mypath\FileWaveClient.msi" -Destination "\\$computer\c$\temp\" -Force
                $command="reg add HKLM\Software\wow6432node\filewave\winclient /v server /t REG_SZ /d $server /f & start /wait msiexec /qn /norestart /l*v+ c:\temp\FileWaveClient.log /i C:\temp\filewaveclient.msi"
                $upgrade=& $mypath\pstools\psexec \\$computer -e -nobanner cmd /c $command
            
                }
            Add-Content -Path "$mypath\output.txt" -Value "$computer, $version, ran batch, $result, $upgrade"
            Add-Content -Path "$mypath\double_check.txt" -Value "$computer"
            } catch {write-host failed $computer}
       }
    }
 
Write-Host "`n'Repaired devices are stored in $mypath\output.txt" -BackgroundColor DarkGreen   
Write-Host "`n`n'Devices can be double checked from $mypath\double_check.txt" -BackgroundColor DarkGreen

