﻿#define where I am working in the file system
$mypath=$MyInvocation.MyCommand.Path
$mypath=Split-Path $mypath -Parent

#presumes a file called double_check.txt exists in current directory
$myinput=Test-Path -path $mypath\double_check.txt
if ($myinput) {
    $mydevices=Get-Content $mypath\double_check.txt
} else {
    write-host "No input file. Aborting.  Please create a text file of device names or IPs as $mypath\double_check.txt" -BackgroundColor DarkRed
    exit
}

#presumes a file called still_bad.txt exists in current directory (for user-readable results)
    #clear previous results, if any
    $myoutput=Test-Path -path $mypath\still_bad.txt
    if ($myoutput) {
        Clear-Content "$mypath\still_bad.txt"
    }


# Server fqdn and creds are needed
# we'll assume the local admin might have connected...save some time typing in fqdn
$key_exists=test-path -path "HKCU:\SOFTWARE\FileWave\FileWave Admin\"
if ($key_exists) { 
    $my_server_reg=Get-ItemProperty -Path "HKCU:\SOFTWARE\FileWave\FileWave Admin\"
    $defaultValue = $my_server_reg.lastServerAddr
    $server = Read-Host -Prompt "`nWhat is the FQDN of your FileWave Server? Or press enter to accept the default [$($defaultValue)]"
    if (!$server) {$server=$defaultValue}
} else {
    $server = Read-Host -Prompt "`nWhat is the FQDN of your FileWave Server?"
}

# Getting the API token is probably the hardest part for the user
Write-Host "`nIf you don't know your API token, check out this article: https://go.filewave.com/api-token"
$token = Read-Host -Prompt "`nEnter your valid base64 API Token (like ezPyMDRlD2UyLTNjN3ItNGNmMS05YjQ5LTkxMmVmYzEzODZmNn0=)"



foreach ($computer in $mydevices) {
#call api and read for device name and filewave client version
$json='{"criteria":{"column":"device_name","component":"Client","operator":"is","qualifier":"Ralph"},"fields":[{"column":"device_name","component":"Client"},{"column":"filewave_client_version","component":"DesktopClient"},{"column":"last_check_in","component":"Client"}],"main_component":"Client","name":"Individual Device"}'
$json=$json -replace ("Ralph",$computer)

$header_dest = @{Authorization=$token}
$api = "https://" + $server +  ":20445/inv/api/v1/query_result_extended/"

$info=Invoke-RestMethod -Method POST -Headers $header_dest -Body $json -ContentType application/json -Uri $api
$version=$info.values.DesktopClient_filewave_client_version
$last_connect=$info.values.Client_last_check_in
#if the client version is correct, then all is good

#otherwise write to a client_monitor check file
if ($version -ne "15.4.0") {
        $online = "Not Online"
        $status = Test-Connection -ComputerName $computer -Count 1 -Quiet

        if ($status) 
            { $online = "Online" }
        Add-Content -Path "$mypath\still_bad.txt" -Value "$computer, $version, $last_connect, $online"
}
}

Write-Host "`n'Devices still not checking in are stored in $mypath\still_bad.txt" -BackgroundColor DarkGreen   